==> haskell-pandoc-lua-marshal-0.2.7-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-marshal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-lua-marshal
version:              0.2.7
visibility:           public
id:                   pandoc-lua-marshal-0.2.7-A76b5eyEURN51dVu04eZKm
key:                  pandoc-lua-marshal-0.2.7-A76b5eyEURN51dVu04eZKm
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel, John MacFarlane
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel, John MacFarlane
homepage:             https://github.com/pandoc/pandoc-lua-marshal
synopsis:             Use pandoc types in Lua
description:
    This package provides functions to marshal and unmarshal
    pandoc document types to and from Lua.

    The values of most types are pushed to pandoc as "userdata"
    objects that wrap a stable pointer to the Haskell value;
    these objects come with methods to access and modify their
    properties.

    Sequences are pushed as normal Lua tables, but are
    augmented with convenience functions.

category:             Foreign
abi:                  6a92a0885f5f23cfc89d9338b4f19598
exposed:              True
exposed-modules:
    Text.Pandoc.Lua.Marshal.AST Text.Pandoc.Lua.Marshal.Alignment
    Text.Pandoc.Lua.Marshal.Attr Text.Pandoc.Lua.Marshal.Block
    Text.Pandoc.Lua.Marshal.Cell Text.Pandoc.Lua.Marshal.Citation
    Text.Pandoc.Lua.Marshal.CitationMode
    Text.Pandoc.Lua.Marshal.Content Text.Pandoc.Lua.Marshal.Filter
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.Inline
    Text.Pandoc.Lua.Marshal.List Text.Pandoc.Lua.Marshal.ListAttributes
    Text.Pandoc.Lua.Marshal.MathType Text.Pandoc.Lua.Marshal.MetaValue
    Text.Pandoc.Lua.Marshal.Pandoc Text.Pandoc.Lua.Marshal.QuoteType
    Text.Pandoc.Lua.Marshal.Row Text.Pandoc.Lua.Marshal.SimpleTable
    Text.Pandoc.Lua.Marshal.TableFoot Text.Pandoc.Lua.Marshal.TableHead
    Text.Pandoc.Lua.Marshal.TableParts

hidden-modules:
    Text.Pandoc.Lua.Marshal.Shared Text.Pandoc.Lua.Topdown
    Text.Pandoc.Lua.SpliceList Text.Pandoc.Lua.Walk

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-lua-marshal-0.2.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-lua-marshal-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-marshal
hs-libraries:         HSpandoc-lua-marshal-0.2.7-A76b5eyEURN51dVu04eZKm
depends:
    aeson-2.1.2.1-HbpdIbO6AMR9AnrzgnqgHA base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 exceptions-0.10.4
    hslua-2.3.0-6W9OHxE4aoS7UC0WnyeGgy
    hslua-list-1.1.2-1E3JjbE9pEvJzDzYqIk0JI
    hslua-marshalling-2.3.1-4hBdSWPYqpt9eJFEHEkBXq
    pandoc-types-1.23.1-BT4Hszv1Wqm7SHuaeiUQ6W
    safe-0.3.21-6LiAUPzeZ5yE2ECncdJJ3m text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-marshal/html/pandoc-lua-marshal.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-marshal/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-lua-marshal-0.2.7-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-marshal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-lua-marshal
version:              0.2.7
visibility:           public
id:                   pandoc-lua-marshal-0.2.7-AA3RXXCawqh6X9VUgIdajh
key:                  pandoc-lua-marshal-0.2.7-AA3RXXCawqh6X9VUgIdajh
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel, John MacFarlane
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel, John MacFarlane
homepage:             https://github.com/pandoc/pandoc-lua-marshal
synopsis:             Use pandoc types in Lua
description:
    This package provides functions to marshal and unmarshal
    pandoc document types to and from Lua.

    The values of most types are pushed to pandoc as "userdata"
    objects that wrap a stable pointer to the Haskell value;
    these objects come with methods to access and modify their
    properties.

    Sequences are pushed as normal Lua tables, but are
    augmented with convenience functions.

category:             Foreign
abi:                  bfeab42ee29ce133122ef9eed2e0a0c1
exposed:              True
exposed-modules:
    Text.Pandoc.Lua.Marshal.AST Text.Pandoc.Lua.Marshal.Alignment
    Text.Pandoc.Lua.Marshal.Attr Text.Pandoc.Lua.Marshal.Block
    Text.Pandoc.Lua.Marshal.Cell Text.Pandoc.Lua.Marshal.Citation
    Text.Pandoc.Lua.Marshal.CitationMode
    Text.Pandoc.Lua.Marshal.Content Text.Pandoc.Lua.Marshal.Filter
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.Inline
    Text.Pandoc.Lua.Marshal.List Text.Pandoc.Lua.Marshal.ListAttributes
    Text.Pandoc.Lua.Marshal.MathType Text.Pandoc.Lua.Marshal.MetaValue
    Text.Pandoc.Lua.Marshal.Pandoc Text.Pandoc.Lua.Marshal.QuoteType
    Text.Pandoc.Lua.Marshal.Row Text.Pandoc.Lua.Marshal.SimpleTable
    Text.Pandoc.Lua.Marshal.TableFoot Text.Pandoc.Lua.Marshal.TableHead
    Text.Pandoc.Lua.Marshal.TableParts

hidden-modules:
    Text.Pandoc.Lua.Marshal.Shared Text.Pandoc.Lua.Topdown
    Text.Pandoc.Lua.SpliceList Text.Pandoc.Lua.Walk

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-lua-marshal-0.2.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-lua-marshal-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-marshal
hs-libraries:         HSpandoc-lua-marshal-0.2.7-AA3RXXCawqh6X9VUgIdajh
depends:
    aeson-2.1.2.1-GayFRV4oUv8L6a1HjAAkY base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 exceptions-0.10.4
    hslua-2.3.0-5z1442XDUZnLOgBdpp6C3G
    hslua-list-1.1.3-Aj5NKGjhxem3LAiZkG88tY
    hslua-marshalling-2.3.1-G6YQw20ud9FK0mLU7sqvy3
    pandoc-types-1.23.1-ApIVcgytA42BrCJ3iLCJYQ
    safe-0.3.21-AbNyMoK0ADF8qenYHSmRn2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-marshal/html/pandoc-lua-marshal.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-marshal/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
